#
# spec file for package Photini
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           Photini
Version:        2018.8.0
Release:        1.2
Summary:        Digital photograph metadata (EXIF, IPTC, XMP) editing application
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
Url:            https://github.com/jim-easterbrook/Photini
Source0:        https://github.com/jim-easterbrook/Photini/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-appdirs >= 1.3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-six >= 1.5
Requires:       libgexiv2-2 >= 0.5
Requires:       python3-appdirs >= 1.3
Requires:       python3-gobject
Requires:       python3-qt5
Requires:       python3-requests >= 2.4.0
Requires:       python3-sip
Requires:       python3-six >= 1.5
Requires:       typelib(GExiv2)
BuildArch:      noarch

%description
A digital photograph metadata (EXIF, IPTC, XMP) editing application.

"Metadata" is said to mean "data about data". In the context of digital
photographs, this means information that is not essential in order to display
the image, but tells something about it. For example, a title and
description of the scene or the date and time and the GPS coordinates of the
camera's position when the picture was taken.

%prep
%setup -q
sed '/^Icon/cIcon=photini' -i src/linux/photini.desktop
# remove shebang
sed -e '1d' -i src/photini/importer.py src/photini/spelling.py src/photini/editor.py

%build
python3 setup.py build
for s in 22 32 48 64 96 128 192 256; do
    convert -strip src/windows/icon.ico[0] -resize ${s}x${s} ${s}.png
done

%install
python3 setup.py install --prefix=%{_prefix} --root %{buildroot}
for s in 22 32 48 64 96 128 192 256; do
mkdir -pv %{buildroot}%{_datadir}/icons//hicolor/${s}x${s}/apps
install -m0644 ${s}.png -T \
               %{buildroot}%{_datadir}/icons//hicolor/${s}x${s}/apps/photini.png
done
chmod -x %{buildroot}%{_datadir}/applications/photini.desktop
%fdupes -s %{buildroot}

%files
%doc CHANGELOG.txt README.rst
%license LICENSE.txt
%{_bindir}/photini
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/photini
%{_datadir}/applications/photini.desktop
%{_datadir}/icons/hicolor/*/apps/photini.png

%changelog
* Tue Aug  7 2018 aloisio@gmx.com
- Update to version 2018.8.0
  * Removed Facebook tab. Their API no longer allows photo uploads.
  * Added "Mapbox" tab - OpenStreetMap data plus aerial imagery.
  * Many changes to maps, e.g. removing "load map" button.
  * Use OpenCage for all address lookups.
* Tue May  1 2018 aloisio@gmx.com
- Update to version 2018.5.0:
  * Improved calculation of "35mm equivalent" focal length.
  * Migrate spell check from PyEnchant to Gspell.
  * Use environment variable to set location of config file.
  * Copy more metadata to sidecar when it is created.
  * Fix problem with QtWebEngine and some PyQt versions.
  * Many other bug fixes and minor improvements.
- Dropped Photini-PyQt5-libGL.patch and Photini-Bing-map.patch
  (merged upstream)
* Wed Apr 25 2018 aloisio@gmx.com
- Added Photini-Bing-map.patch
* Wed Apr 25 2018 aloisio@gmx.com
- Added Photini-PyQt5-libGL.patch
* Sat Feb 10 2018 aloisio@gmx.com
- Update to 2018.2.0
  * All maps are faster and less buggy.
* Fri Dec  1 2017 aloisio@gmx.com
- Update to 2017.12.0
  * Add 'rating' to descriptive tab.
  * Don't try to upload files over 1 GByte to Flickr.
  * Fix bug with thembnails of portrait format images.
- Spec cleanup
* Tue Oct  3 2017 aloisio@gmx.com
- Update to 2017.10.0
  * Use timezone metadata from some Canon cameras.
  * Make thumbnails 160x120 as specified by DCF.
  * Fix bug in localisation of uploader tabs.
  * Substantial rewrite of metadata handling.
* Fri Aug 18 2017 aloisio@gmx.com
- Update to 2017.08.1
  * Added option to preserve file timestamps.
  * Added option to change copyright boilerplate text.
  * Added config file option to change application style.
  * Fix bug with importing files with spaces in their names.
  * Changed importer template marker from () to {}.
* Wed Aug  9 2017 aloisio@gmx.com
- Update to version 2017.8
  * Use Exif/Xmp thumbnails instead of computing from image data.
  * Improved video file metadata reading.
  * Added context menu to choose one of them.
  * Added context menu to image selector.
  * Can regenerate thumbnail, including from video files.
- Disabled tests (none was actually being performed)
* Fri Jun  2 2017 aloisio@gmx.com
- Update to version 2017.6
  * Add location address metadata to map tabs.
  * Fix bug in Flickr uploader if user hasn't set a "buddy" icon.
  * Use OpenCage Data for OSM map search and address lookup.
* Fri May  5 2017 jengelh@inai.de
- Remove redundant filler words from description.
* Tue May  2 2017 aloisio@gmx.com
- Added multiple icon sizes
* Tue May  2 2017 aloisio@gmx.com
- Update to version 2017.5
  * Migrate Bing map from v7 to v8 of Bing API.
  * Many other map improvements.
  * Time adjustment offset now includes time zone.
* Mon May  1 2017 adam.reichold@t-online.de
- Bump to latest upstream version
* Mon Feb 20 2017 aloisio@gmx.com
- Minor change
* Mon Feb 20 2017 aloisio@gmx.com
- Initial package (version 2016.12.0)
